==> openwebbeans-1.2.8-source-release.zip: openwebbeans-1.2.8/webbeans-impl/src/test/java/org/apache/webbeans/test/component/intercept/Interceptor1.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component.intercept;

import javax.annotation.PostConstruct;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;

public class Interceptor1
{
    @AroundInvoke
    public Object intercept(InvocationContext context) throws Exception
    {
        System.out.println("Interceptor class : " + Interceptor1.class.getSimpleName());
        context.getContextData().put("key", "value");

        return context.proceed();
    }

    @PostConstruct
    public void construct(InvocationContext ctx) throws RuntimeException
    {
        ctx.getContextData().put("key1", "value1");
        try
        {
            ctx.proceed();
        }
        catch (Exception e)
        {
            throw new RuntimeException(e);
        }
    }

}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/component/intercept/Interceptor1.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component.intercept;

import jakarta.annotation.PostConstruct;
import jakarta.interceptor.AroundInvoke;
import jakarta.interceptor.InvocationContext;

public class Interceptor1
{
    @AroundInvoke
    public Object intercept(InvocationContext context) throws Exception
    {
        System.out.println("Interceptor class : " + Interceptor1.class.getSimpleName());
        context.getContextData().put("key", "value");

        return context.proceed();
    }

    @PostConstruct
    public void construct(InvocationContext ctx) throws RuntimeException
    {
        ctx.getContextData().put("key1", "value1");
        try
        {
            ctx.proceed();
        }
        catch (Exception e)
        {
            throw new RuntimeException(e);
        }
    }

}
